@@ -1,6 +1,6 @@
 library(AnchorRegression)
 
-
+set.seed(1)
 x <- as.data.frame(matrix(data = rnorm(100),nrow = 100,ncol = 10))
 
 anchor <- as.data.frame(matrix(data = rnorm(20),nrow = 100,ncol = 2))
@@ -11,3 +11,4 @@ target_variable <- 'V2'
 
 
 anchor_regression(x, anchor, gamma, target_variable)
+anchor_stability(x, anchor, target_variable, lambda, alpha=0.05)
